==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/OnBalanceVolumeIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { OnBalanceVolumeIndicatorDescription } from "./OnBalanceVolumeIndicatorDescription";
/**
 * @hidden
 */
export let OnBalanceVolumeIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class OnBalanceVolumeIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (OnBalanceVolumeIndicatorDescriptionMetadata.a == null) {
                OnBalanceVolumeIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OnBalanceVolumeIndicatorDescriptionMetadata.c(OnBalanceVolumeIndicatorDescriptionMetadata.a);
            }
            if (a.k(OnBalanceVolumeIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(OnBalanceVolumeIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            OnBalanceVolumeIndicatorDescriptionMetadata.b(a);
            a.ad("OnBalanceVolumeIndicator", () => new OnBalanceVolumeIndicatorDescription());
            a.ac("OnBalanceVolumeIndicator", OnBalanceVolumeIndicatorDescriptionMetadata.a);
        }
    }
    OnBalanceVolumeIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(OnBalanceVolumeIndicatorDescriptionMetadata, 'OnBalanceVolumeIndicatorDescriptionMetadata');
    OnBalanceVolumeIndicatorDescriptionMetadata.a = null;
    return OnBalanceVolumeIndicatorDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/OnBalanceVolumeIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { OnBalanceVolumeIndicatorDescription } from "./OnBalanceVolumeIndicatorDescription";
/**
 * @hidden
 */
export let OnBalanceVolumeIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class OnBalanceVolumeIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (OnBalanceVolumeIndicatorDescriptionMetadata.a == null) {
                OnBalanceVolumeIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OnBalanceVolumeIndicatorDescriptionMetadata.c(OnBalanceVolumeIndicatorDescriptionMetadata.a);
            }
            if (a.k(OnBalanceVolumeIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(OnBalanceVolumeIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            OnBalanceVolumeIndicatorDescriptionMetadata.b(a);
            a.ae("OnBalanceVolumeIndicator", () => new OnBalanceVolumeIndicatorDescription());
            a.ad("OnBalanceVolumeIndicator", OnBalanceVolumeIndicatorDescriptionMetadata.a);
        }
    }
    OnBalanceVolumeIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(OnBalanceVolumeIndicatorDescriptionMetadata, 'OnBalanceVolumeIndicatorDescriptionMetadata');
    OnBalanceVolumeIndicatorDescriptionMetadata.a = null;
    return OnBalanceVolumeIndicatorDescriptionMetadata;
})();
